@@ -56,7 +56,7 @@ def _make_class_properties(cls):
         for name, field in supercls.fields.items():
             if name not in cls.fields:
                 cls.fields[name] = field
-    for name, field in six.iteritems(cls.fields):
+    for name, field in cls.fields.items():
         if not isinstance(field, obj_fields.Field):
             raise exception.ObjectFieldInvalid(
                 field=name, objname=cls.obj_name())
@@ -208,7 +208,7 @@ def remotable(fn):
         if self.indirection_api:
             updates, result = self.indirection_api.object_action(
                 ctxt, self, fn.__name__, args, kwargs)
-            for key, value in six.iteritems(updates):
+            for key, value in updates.items():
                 if key in self.fields:
                     field = self.fields[key]
                     # NOTE(ndipanov): Since VersionedObjectSerializer will have
@@ -314,7 +314,7 @@ class VersionedObject(object):
                                   field.stringify(getattr(self, name)) or
                                   '<?>'))
                       for name, field in sorted(self.fields.items())]))
-        if not six.PY3:
+        if six.PY2:
             repr_str = encodeutils.safe_encode(repr_str, incoming='utf-8')
         return repr_str
 
@@ -706,12 +706,27 @@ class ComparableVersionedObject(object):
             return self.obj_to_primitive() == obj.obj_to_primitive()
         return NotImplemented
 
+    def __hash__(self):
+        return super(ComparableVersionedObject, self).__hash__()
+
     def __ne__(self, obj):
         if hasattr(obj, 'obj_to_primitive'):
             return self.obj_to_primitive() != obj.obj_to_primitive()
         return NotImplemented
 
 
+class TimestampedObject(object):
+    """Mixin class for db backed objects with timestamp fields.
+
+    Sqlalchemy models that inherit from the oslo_db TimestampMixin will include
+    these fields and the corresponding objects will benefit from this mixin.
+    """
+    fields = {
+        'created_at': obj_fields.DateTimeField(nullable=True),
+        'updated_at': obj_fields.DateTimeField(nullable=True),
+    }
+
+
 class VersionedObjectDictCompat(object):
     """Mix-in to provide dictionary key access compatibility
 
@@ -933,7 +948,7 @@ class VersionedObjectSerializer(messaging.NoOpSerializer):
         iterable = values.__class__
         if issubclass(iterable, dict):
             return iterable([(k, action_fn(context, v))
-                             for k, v in six.iteritems(values)])
+                             for k, v in values.items()])
         else:
             # NOTE(danms, gibi) A set can't have an unhashable value inside,
             # such as a dict. Convert the set to list, which is fine, since we
@@ -1129,7 +1144,7 @@ def obj_tree_get_versions(objname, tree=None):
     level object with other objects as fields. It walks the tree recursively
     to determine all the objects (by symbolic name) that could be contained
     within the top-level object, and the maximum versions of each. The result
-    is a dict like:
+    is a dict like::
 
       {'MyObject': '1.23', ... }
 
